@@ -15,7 +15,7 @@ has fields => (
     coerce => sub {
         my $fields = $_[0];
         if (ref $fields eq 'ARRAY') { return $fields }
-        if (ref $fields eq 'HASH')  { return [keys %$fields] }
+        if (ref $fields eq 'HASH')  { return [sort keys %$fields] }
         return [split ',', $fields];
     },
 );
@@ -137,4 +137,4 @@ L<Catmandu::Exporter>
 
 =cut
 
-1;
\ No newline at end of file
+1;
